# Majority Judgment

## Common language

The Majority Judgment asks us to answer to a specific, operationally actionable,
question about several choices, by judging each choice in an absolute way
(i.e. such that the removal or addition of choices
does not change our evaluation of the other choices)
by giving them a grade (or level) on a common scale.

This common scale contains as many grades as our supposed common expertise
is able to distinguish, in order to faithfully represent
the properties of the attribute it tries to measure.
Hence, a common scale should be crafted for each different attribute.
The inter-subjective meaning of each grade
being reinforced by the practice of judgments.

### Examples

Examples of common scales could be:
- [“To Reject”, “Insufficient”, “Acceptable”, “Good”, “Very Good”] for quality,
- [“Very Bad”, “Bad”, “Rather Bad”, “Rather Good”, “Good”, “Very Good”] for quality,
- [“Strongly Against”, “Against”, “Rather Against”, “Indifferent”, “Rather For”, “For”, “Strongly For”] for adhesion,
- [“Very Wrong”, “Wrong”, “Rather Wrong”, “Rather Well”, “Well”, “Very Well”] for rightness,
- [“None”, “Not Enough”, “Enough”, “Much”, “Too Much”] for quantity,
- [“To Do”, “Prioritized”, “Blocking”, “Urgent”, “Too Urgent”] for priority,
- [“Useless”, “Interesting”, “Useful”, “Indispensable”, “Enslaving”] for utility.

Note that the more a scale enables to judge in the absolute,
the more resistant to Arrow's paradox it is.
Here, depending on the judges,
some of the above scales using the “Very X”/“X”/“Rather X” structure,
may be too subjective to discourage the relative comparison of choices,
this said, if it is the exact expressions used in everyday parlance,
it may be sensible to use them.
In any case, to not confuse/skew the judgments it is important
that a scale spans only on a single dimension/criteria.

## Judging one choice

The “majority grade” is the fundamental indicator of the Majority Judgment.
Located at the middle of the distribution of grades obtained by a choice,
it is also known by high school students under the name “median”,
that is to say, the grade such that 50% of grades are lower or egal to it,
and 50% are greater or egal to it.
Such that regardless the way we look at it,
there is always an absolute majority among the judges
which agree to defend the majority grade against any other grade.
In other words: whoever among the judges is against, is necessarily in minority.
Therefore, the majority grade brings the judges together by minimizing
the number of unsatisfied among them.
Like so, the majority grade enables us to overcome the old notion of majority
expressed on the count of our scattered voices, which divides us.

Moreover, one can see that the farest an individual judgment is
from the majoritary grade, the less impact it has on the result.
This rewards honest individual judgments,
by ignoring as near as may be the most cranky or strategic judgements.

If the number of individual judgments is small and even
(eg. for 6 judges: [“Insufficient”, “Acceptable”, “Acceptable”, “Good”, “Good”, “Good”]),
there is however a probability that two different grades
border the middlemost of this dilated scale (here: “Acceptable” and “Good”).
But only the lower grade (here: “Acceptable”) rewards consensus,
and thus is considered to be the most consensual.
Indeed, if any other choice obtains less scattered judgments
(eg. [“Acceptable”, “Acceptable”, “Acceptable”, “Acceptable”, “Good”, “Good”])
all enclosed into these two grades,
it will obtain a majoritary grade
greater or egal (here: “Acceptable”) to the one of this choice.
Which would not necessarily be the case with the greater grade (here: “Good”).

## Ranking many choices

The ranking of choices is done by comparing their respective majority grades.
Those obtaining the same majority grade are compared further
by applying again the principle of minimizing unsatisfied judges :
one judgment giving this majority grade is removed of their distributions
until two different majority grades are obtained,
or both choices precisely have the same distribution of individual judgments.
In which case, it is enough that one judge
change the grade it gives to at least one of those choices,
and/or it may be wise to also judge on other criterias.

## Properties

The Majority Judgment is:

- allowing anonymity:
  interchanging the names of judges does not change the outcome:
  all judges are given an equal power.

- neutral:
  interchanging the names of choices does not change the outcome:
  all choices are treated equally.

- complete:
  every choice is either superior or inferior
  to any other choice, or both when equal.
  Hence the Majority Judgement is not subject
  to Condorcet's paradox.

- monotone:
  if a choice is superior or egal to another one,
  and a judge increases its grade for it,
  it becomes strictly superior.

- transitive:
  if a first choice is superior to a second one,
  and this second one is superior to a third,
  then the first is superior to the third).

- coherent:
  it is independent of irrelevant alternatives as formulated by Nash-Chernoff:
  removal or addition of choices does not change
  the judges’ evaluations of the other choices.
  Hence the Majority Judgement is not subject
  to Arrow's paradox.

- strategy-proof-in-grading:
  judging a choice higher or lower
  than our intimate judgement has the opposite impact
  on its most consensual majority grade.

- partially strategy-proof-in-ranking:
  increasing (resp. decreasing) the rank of a choice with respect to another choice,
  can not decrease (resp. increase) the rank of this other choice.

- not Condorcet-consistent:
  not guarantying the selection of a choice
  which is preferred by a majority against every of the others separately.
  
  Except when the electorate is “polarized”:
  when the higher (resp. the lower) a judge evaluates one choice the lower (resp. the higher)
  she/he evaluates the other, so there can be no consensus;
  hence when judges are most tempted to manipulate.
  
  This property is judged undesirable, by Michel Balinski and Rida Laraki,
  as they prove how easily the Majority Rule can go wrong when voting
  on but two candidates, let alone more.

- not excluding the no-show paradox:
  it may be better for a judge not to judge
  than to express her/his opinion sincerely because her/his vote
  can tip the scales against his favorite choice.
  
  This property is judged insignificant, by Michel Balinski and Rida Laraki,
  when compared with the serious problems of methods of election,
  the Arrow and Condorcet paradoxes and strategic manipulation.
  Moreover, the only methods based on measuring that exclude
  the no-show paradox are point-summing methods,
  which, amongst other drawbacks, are highly manipulable.

## Resources
- [Majority Judgment: Measuring, Ranking, and Electing](http://libgen.io/book/index.php?md5=BF67AA4298C1CE7633187546AA53E01D) (en)
- [Majority Judgment vs. Majority Rule](http://www.lamsade.dauphine.fr/sites/default/IMG/pdf/cahier_377.pdf) (en)
- [Judge : Don't Vote!](https://1007421605497013616-a-1802744773732722657-s-sites.googlegroups.com/site/ridalaraki/xfiles/BalinskiLarakiJudgeDontVotecahierderecherche2010-27.pdf) (en)
- [Jugement majoritaire versus vote majoritaire (via les présidentielles 2011-2012)](https://www.cairn.info/revue-francaise-d-economie-2012-4-page-11.htm) (fr)
- [Majority Judgment vs. Majority Rule](http://www.lamsade.dauphine.fr/sites/default/IMG/pdf/cahier_377.pdf) (en)
- [What Should “Majority Decision” Mean?](https://1984f707-a-62cb3a1a-s-sites.googlegroups.com/site/ridalaraki/xfiles/BalinskiLaraki%28ElsterBook%292014.pdf?attachauth=ANoY7cqCY4F_kQdtBc2d9EtUDNNPqtuoOYj98ThvPFukdXBkzogggu_WcKe2SryAQ9tq0P1HaGHHhD6sOdBNQ-ttaQ9XJUjVPHVCsMp4PDuX_DlvMv8MYqG6SGy_m39Q9tztOWezturc9q50RMHs0CKEGqiBqnRlyP4BFo5i4PqHDT5nD2v0HTsINWs6PooIz-bZpeuUXST1A30ojKDQ_b5xsK50RFMkJT7LG-p441cGlUOQWIGYikd2XglJdBJr0N5YuL80ZePd&attredirects=0) (en)
- [Condorcet-Consistent and Approximately Strategyproof Tournament Rules](https://arxiv.org/pdf/1605.09733.pdf) (en)
